yt.frontends.athena.fields.AthenaFieldInfo.add_field — The yt Project 3.2-dev documentation

# yt.frontends.athena.fields.AthenaFieldInfo.add_field

`AthenaFieldInfo.` `add_field`(name, function=None, **kwargs)

  Add a new field, along with supplemental metadata, to the list of available fields. This respects a number of arguments, all of which are passed on to the constructor for `DerivedField`.

  Parameters: | name : str is the name of the field. function : callable A function handle that defines the field. Should accept arguments (field, data) units : str A plain text string encoding the unit. Powers must be in python syntax (** instead of ^). If set to “auto” the units will be inferred from the return value of the field function. take_log : bool Describes whether the field should be logged validators : list A list of `FieldValidator` objects particle_type : bool Is this a particle (1D) field? vector_field : bool Describes the dimensionality of the field. Currently unused. display_name : str A name used in the plots